@@ -44,7 +44,7 @@ Mail    : 1078539713@qq.com
 
 '''
 
-__version__ = "1.0.2"
+__version__ = "1.0.3"
 
 
 import wx
@@ -354,12 +354,11 @@ class MyFrame(wx.Frame):
             subtit = self.text_ctrl_5.GetValue()
 
             pp = PrintPreview(self.psm_list, self.psm_title,
-                              subtit, col=int(self.text_ctrl_3.GetValue()))
+                              subtit, col=int(self.text_ctrl_3.GetValue()),docxpath=self.config.c.get('config','docx')+os.sep)
             pp.produce()  # 生成docx
             self.psm_list.clear()  # 清空打印列表。
-            print('开始移动文件')
-            self.movdocx()
-            wx.MessageBox('文件发布成功，保存在'+self.config.c.get('config','docx')+os.sep+'docx 目录下，请查看！！', '成功提示',
+            # self.movdocx()
+            wx.MessageBox('文件发布成功，保存在'+self.config.c.get('config','docx')+'目录下，请查看！！', '成功提示',
                           wx.OK | wx.ICON_INFORMATION)
 
     def saveSignum(self, e):
@@ -422,7 +421,7 @@ class MyFrame(wx.Frame):
         if dlg.ShowModal() == wx.ID_OK:
             #print(dlg.GetPath())
             self.config.saveDocx(dlg.GetPath())
-            wx.MessageBox('设置文件保存目录'+self.config.c.get('config','docx')+os.sep+'docx 成功！', '成功提示',
+            wx.MessageBox('设置文件保存目录为：'+self.config.c.get('config','docx')+os.sep, '成功提示',
                           wx.OK | wx.ICON_INFORMATION)
 
 # end of class MyFrame
